Module cooldown

Module cooldown 

Cooldown-based load balancer with per-entry reuse intervals.

Structs

Cooldown
A load balancer that allocates items based on a cooldown interval. Each entry can only be reused after its interval has elapsed since the last allocation.
Entry
A single entry in the cooldown load balancer.