pub struct Cooldown<T>{ /* private fields */ }Expand description
A load balancer that allocates items based on a cooldown interval. Each entry can only be reused after its interval has elapsed since the last allocation.
Implementations
Sourceimpl<T> Cooldown<T>
impl<T> Cooldown<T>
Sourcepub fn new(entries: Vec<(Duration, T)>) -> Self
pub fn new(entries: Vec<(Duration, T)>) -> Self
Create a new Cooldown with a list of (interval, value) pairs.
Each value will only be available after its interval has passed since the last allocation.