Module proxy_pool

Module proxy_pool 

Proxy pool with health checking and latency-based sorting.

Structs

ProxyPool
An advanced proxy pool that measures latency, removes dead proxies, and sorts proxies by response time in ascending order.