pub struct Random<T>{ /* private fields */ }Expand description
A load balancer that randomly selects an entry.
Implementations
Sourceimpl<T> Random<T>
impl<T> Random<T>
Sourcepub async fn update<F, R, N>(&self, handler: F) -> Result<N>
pub async fn update<F, R, N>(&self, handler: F) -> Result<N>
Run an async callback with access to the internal state.
Sourcepub async fn update_timer<F, R>(
&self,
handler: F,
interval: Duration,
) -> Result<JoinHandle<()>>
pub async fn update_timer<F, R>( &self, handler: F, interval: Duration, ) -> Result<JoinHandle<()>>
Spawn a background task that calls handler every interval.
The handler is called once immediately; if that initial call fails the error is returned and no background task is spawned.