pub struct RoundRobin<T>{ /* private fields */ }Expand description
A round-robin load balancer that selects entries in sequential order.
Implementations
Sourceimpl<T> RoundRobin<T>
impl<T> RoundRobin<T>
Sourcepub async fn update<F, R, N>(&self, handler: F) -> Result<N>
pub async fn update<F, R, N>(&self, handler: F) -> Result<N>
Update the inner state using an async callback.
Sourcepub async fn update_timer<F, R>(
&self,
handler: F,
interval: Duration,
) -> Result<JoinHandle<()>>
pub async fn update_timer<F, R>( &self, handler: F, interval: Duration, ) -> Result<JoinHandle<()>>
Spawn a background task that calls handler every interval.
The handler is called once immediately; if that initial call fails the error is returned and no background task is spawned.