Module proxy_pool
load_
balancer
0.5.0
Module proxy_
pool
Module Items
Structs
In crate load_
balancer
load_balancer
Module
proxy_
pool
Proxy pool with health checking and latency-based sorting.
Structs

Proxy
Pool
An advanced proxy pool that measures latency, removes dead proxies, and sorts proxies by response time in ascending order.