pub trait LoadBalancer<T>:
Send
+ Sync
+ Clone
+ 'static {
// Required methods
fn alloc(&self) -> impl Future<Output = T> + Send;
fn try_alloc(&self) -> Option<T>;
}Expand description
A generic load balancer trait for allocating resources from a pool.
Implementors manage a collection of items and distribute them according to their specific strategy (round-robin, random, cooldown, etc.).
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".